==> org.eclipse.handly.ui.source_0.3.0.v20150617-1600.jar: org/eclipse/handly/ui/preference/StringPreference.java <==
/*******************************************************************************
 * Copyright (c) 2014 1C LLC.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Vladimir Piskarev (1C) - initial API and implementation
 *******************************************************************************/
package org.eclipse.handly.ui.preference;

import org.eclipse.jface.preference.IPreferenceStore;

/**
 * Implements a string-valued preference.
 * The preference is stored in {@link IPreferenceStore}.
 */
public class StringPreference
    extends AbstractPreference
    implements IStringPreference
{
    /**
     * Creates a new string-valued preference
     * with the given name and the given store.
     *
     * @param name the preference name (not <code>null</code>)
     * @param store the preference store (not <code>null</code>)
     */
    public StringPreference(String name, IPreferenceStore store)
    {
        super(name, store);
    }

    @Override
    public final String getValue()
    {
        return getStore().getString(getName());
    }

    @Override
    public final void setValue(String value)
    {
        getStore().setValue(getName(), value);
    }
    
    /**
     * Sets the default value for this preference.
     * <p>
     * Note that the current value of the preference is affected if
     * the preference's current value was its old default value, in which
     * case it changes to the new default value. If the preference's current
     * is different from its old default value, its current value is
     * unaffected. No preference change events are reported by changing default
     * values.
     * </p>
     *
     * @param value the new default value for the preference
     */
    public final void setDefault(String value)
    {
        getStore().setDefault(getName(), value);
    }
}

==> org.eclipse.handly.ui.source_1.7.13.v20251204-1500.jar: org/eclipse/handly/ui/preference/StringPreference.java <==
/*******************************************************************************
 * Copyright (c) 2014, 2018 1C-Soft LLC and others.
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Vladimir Piskarev (1C) - initial API and implementation
 *******************************************************************************/
package org.eclipse.handly.ui.preference;

import org.eclipse.jface.preference.IPreferenceStore;

/**
 * Implements a string-valued preference.
 * The preference is stored in an {@link IPreferenceStore}.
 */
public class StringPreference
    extends AbstractPreference
    implements IStringPreference
{
    /**
     * Creates a new string-valued preference
     * with the given name and the given store.
     *
     * @param name the preference name (not <code>null</code>)
     * @param store the preference store (not <code>null</code>)
     */
    public StringPreference(String name, IPreferenceStore store)
    {
        super(name, store);
    }

    @Override
    public final String getValue()
    {
        return getStore().getString(getName());
    }

    @Override
    public final void setValue(String value)
    {
        getStore().setValue(getName(), value);
    }

    /**
     * Sets the default value for this preference.
     * <p>
     * Note that if the preference's current value equals the old default value,
     * the current value changes to the new default value. No preference change
     * events are reported by changing default values.
     * </p>
     *
     * @param value the new default value for this preference
     */
    public final void setDefault(String value)
    {
        getStore().setDefault(getName(), value);
    }
}
